parse_args

Function parse_args 

pub fn parse_args<'a>(args: &'a ArgMatches<'_>) -> Result<ParseResult<'a>, ()>
Parses command line arguments for source and destination folders and creates the destination folder if it does not exist

Errors

This function will return an error in the following situations, but is not limited to just these cases:

  • The source folder is not a valid directory
  • The destination folder could not be created